# Modeling: Tech Category (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/tech-category-modeling-v3#overview)
  * [Resources](https://help.sap.com/docs/leanix/ea/tech-category-modeling-v3#resources)


In this section, you will find a best practice Tech Category model to upload to your workspace.
